@@ -115,22 +115,23 @@ class MainLog(BaseLog):
                         action_code = f.__name__  # 接口操作码
                         request_url = request.url.encode('utf-8')
                         request_content = request.data
-                        request_length = len(request_content)  # request正文长度
+                        if request_content:
+                            request_content = check_resp_items(request_content)
                         order_id, phone_num = getattr(request, 'order_id', None), getattr(request, 'phone_num',
                                                                                           None)
                         if request.method == "GET":
                             transaction_id = request.args.get("id", "") or request.args.get("htId", "")
                         elif request.method == "POST":
-                            transaction_id = json.loads(request_content).get('id')
+                            transaction_id = request_content.get('id')
                         else:
                             transaction_id = str(uuid.uuid1()).replace("-", "")
+                        request_content = json.dumps(request_content)
+                        request_length = len(request_content)  # request正文长度
                         # 接口后置流水日志处理
                         str_ret = ret_to_str(ret)
                         if str_ret:
                             str_ret = check_resp_items(str_ret)
-                        if request_content:
-                            request_content = check_resp_items(request_content)
-                        response_content = str_ret
+                        response_content = json.dumps(str_ret)
                         response_length = len(response_content)  # response正文长度
                         log_head_length = 80
                         flow = log_head_length + request_length + response_length
@@ -157,7 +158,7 @@ class MainLog(BaseLog):
                                                                  mandatory=False
                                                                  )
                         """加入日志平台对内流水日志"""
-                        response_data = is_json(str_ret)
+                        response_data = str_ret
                         if response_data:
                             if str(response_data.get('code', "")) or str(response_data.get(u'code', "")):
                                 response_code = str(response_data.get('code', "")) or str(response_data.get(u'code', ""))
@@ -177,7 +178,7 @@ class MainLog(BaseLog):
                                           request_headers=get_headers_data(request.headers),
                                           request_content=request_content,
                                           response_headers=get_headers_data(ret.headers),
-                                          response_content=str_ret,
+                                          response_content=response_content,
                                           response_time=response_time,
                                           response_code=response_code,
                                           http_status_code=ret.status_code,
